@@ -27,8 +27,10 @@ from .types import (
     Choice,
     ChoiceType,
     ColorType,
-    CountryType,
     Country,
+    CountryType,
+    DateRangeType,
+    DateTimeRangeType,
     EmailType,
     instrumented_list,
     InstrumentedList,
@@ -36,12 +38,13 @@ from .types import (
     IPAddressType,
     JSONType,
     LocaleType,
+    NumericRangeType,
     Password,
     PasswordType,
     PhoneNumber,
     PhoneNumberType,
-    ScalarListType,
     ScalarListException,
+    ScalarListType,
     TimezoneType,
     TSVectorType,
     URLType,
@@ -53,27 +56,30 @@ from .types import (
 )
 
 
-__version__ = '0.23.0'
+__version__ = '0.23.1'
 
 
 __all__ = (
     aggregated,
     batch_fetch,
     coercion_listener,
+    create_database,
+    create_mock_engine,
+    database_exists,
     defer_except,
+    drop_database,
     escape_like,
     generates,
     generic_relationship,
     identity,
     instrumented_list,
     merge,
+    mock_engine,
     naturally_equivalent,
     primary_keys,
     proxy_dict,
-    render_statement,
     render_expression,
-    create_mock_engine,
-    mock_engine,
+    render_statement,
     sort_query,
     table_name,
     with_backrefs,
@@ -81,16 +87,19 @@ __all__ = (
     Choice,
     ChoiceType,
     ColorType,
-    CountryType,
     Country,
+    CountryType,
+    DateRangeType,
+    DateTimeRangeType,
     EmailType,
     ImproperlyConfigured,
     InstrumentedList,
+    IntRangeType,
     IPAddressType,
     JSONType,
     LocaleType,
     Merger,
-    IntRangeType,
+    NumericRangeType,
     Password,
     PasswordType,
     PhoneNumber,
@@ -102,9 +111,6 @@ __all__ = (
     TSVectorType,
     URLType,
     UUIDType,
-    database_exists,
-    create_database,
-    drop_database,
     INT4RANGE,
     INT8RANGE,
     DATERANGE,
