@@ -13,7 +13,10 @@ from .range import (
     INT8RANGE,
     DATERANGE,
     NUMRANGE,
+    DateRangeType,
+    DateTimeRangeType,
     IntRangeType,
+    NumericRangeType,
 )
 from .password import Password, PasswordType
 from .phone_number import PhoneNumber, PhoneNumberType
@@ -30,13 +33,16 @@ __all__ = (
     Choice,
     ChoiceType,
     ColorType,
-    CountryType,
     Country,
+    CountryType,
+    DateRangeType,
+    DateTimeRangeType,
     EmailType,
+    IntRangeType,
     IPAddressType,
     JSONType,
     LocaleType,
-    IntRangeType,
+    NumericRangeType,
     Password,
     PasswordType,
     PhoneNumber,
