@@ -16,8 +16,61 @@ Some good reading for practical interval implementations:
 http://wiki.postgresql.org/images/f/f0/Range-types.pdf
 
 
+Range type operators
+--------------------
+
+SQLAlchemy-Utils supports many range type operators. These operators follow the `intervals` package interval coercion rules.
+
+So for example when we make a query such as:
+
+::
+
+    session.query(Car).filter(Car.price_range == 300)
+
+
+It is essentially the same as:
+
+::
+
+    session.query(Car).filter(Car.price_range == DecimalInterval([300, 300]))
+
+
+The coercion is provided for convenience.
+
+
+Comparison operators
+^^^^^^^^^^^^^^^^^^^^
+
+All range types support all comparison operators (>, >=, ==, !=, <=, <).
+
+::
+
+    Car.price_range < [12, 300]
+
+    Car.price_range == [12, 300]
+
+    Car.price_range < 300
+
+    Car.price_range > (300, 500)
+
+
+Membership operators
+^^^^^^^^^^^^^^^^^^^^
+
+::
+
+    Car.price_range.contains([300, 500])
+
+    Car.price_range.contained_by([300, 500])
+
+    Car.price_range.in_([[300, 500], [800, 900]])
+
+    ~ Car.price_range.in_([[300, 400], [700, 800]])
+
+
 .. _intervals: https://github.com/kvesteri/intervals
 """
+from collections import Iterable
 intervals = None
 try:
     import intervals
@@ -74,21 +127,49 @@ ischema_names['tstzrange'] = TSTZRANGE
 
 class RangeComparator(types.TypeEngine.Comparator):
     @classmethod
-    def coerce_arg(cls, func):
+    def coerced_func(cls, func):
         def operation(self, other, **kwargs):
-            coerced_types = (
-                self.type.interval_class.type,
-                tuple,
-                list,
-            ) + six.string_types
-
-            if isinstance(other, coerced_types):
-                other = self.type.interval_class(other)
+            other = self.coerce_arg(other)
             return getattr(types.TypeEngine.Comparator, func)(
                 self, other, **kwargs
             )
         return operation
 
+    def coerce_arg(self, other):
+        coerced_types = (
+            self.type.interval_class.type,
+            tuple,
+            list,
+        ) + six.string_types
+
+        if isinstance(other, coerced_types):
+            return self.type.interval_class(other)
+        return other
+
+    def in_(self, other):
+        if (
+            isinstance(other, Iterable) and
+            not isinstance(other, six.string_types)
+        ):
+            other = map(self.coerce_arg, other)
+        return super(RangeComparator, self).in_(other)
+
+    def notin_(self, other):
+        if (
+            isinstance(other, Iterable) and
+            not isinstance(other, six.string_types)
+        ):
+            other = map(self.coerce_arg, other)
+        return super(RangeComparator, self).notin_(other)
+
+    def contains(self, other, **kwargs):
+        other = self.coerce_arg(other)
+        return self.op('@>')(other)
+
+    def contained_by(self, other, **kwargs):
+        other = self.coerce_arg(other)
+        return self.op('<@')(other)
+
 
 funcs = [
     '__eq__',
@@ -104,7 +185,7 @@ for func in funcs:
     setattr(
         RangeComparator,
         func,
-        RangeComparator.coerce_arg(func)
+        RangeComparator.coerced_func(func)
     )
 
 
